@@ -7,14 +7,16 @@ Currency::Currency(QWidget *parent) :
 {
     ui->setupUi(this);
 
-    ui->lineEdit_taxRate->setValidator(new QDoubleValidator(0, 100, 1, this));
-    ui->lineEdit_tipRate->setValidator(new QDoubleValidator(0, 100, 1, this));
+    ui->lineEdit_taxRate->setValidator(new QDoubleValidator(0, 100, 2, this));
+    ui->lineEdit_tipRate->setValidator(new QDoubleValidator(0, 100, 2, this));
     ui->lineEdit_Currency1->setValidator(new QDoubleValidator(0, 9999999, 6, this));
     ui->lineEdit_Currency2->setValidator(new QDoubleValidator(0, 9999999, 6, this));
     ui->lineEdit_taxRate->setText(mvSettings.value("TaxRate").toString());
     ui->lineEdit_tipRate->setText(mvSettings.value("TipRate").toString());
     mvCurrency1 = mvSettings.value("Currency1").toString();
     mvCurrency2 = mvSettings.value("Currency2").toString();
+    mvAutoUpdate = mvSettings.value("AutoUpdate").toBool();
+    ui->checkBox_AutoUpdate->setChecked(mvAutoUpdate);
 
     displayRate();
     updateList();
@@ -86,8 +88,9 @@ void Currency::on_pushButton_Apply_clicked()
 {
     mvSettings.setValue("Currency1", mvCurrency1);
     mvSettings.setValue("Currency2", mvCurrency2);
-    mvSettings.setValue("TaxRate", ui->lineEdit_taxRate->text().toFloat());
-    mvSettings.setValue("TipRate", ui->lineEdit_tipRate->text().toFloat());
+    mvSettings.setValue("TaxRate", ui->lineEdit_taxRate->text().toDouble());
+    mvSettings.setValue("TipRate", ui->lineEdit_tipRate->text().toDouble());
+    mvSettings.setValue("AutoUpdate", mvAutoUpdate);
 
     if (mvCurrency1 != "EUR") {
         mvSettings.setValue("Currency/" + mvCurrency1, ui->lineEdit_Currency1->text().toDouble());
@@ -110,3 +113,13 @@ void Currency::on_pushButton_Edit_clicked()
     displayRate();
     updateList();
 }
+
+
+void Currency::on_checkBox_AutoUpdate_clicked(bool checked)
+{
+    if (checked) {
+        mvAutoUpdate = true;
+    } else {
+        mvAutoUpdate = false;
+    }
+}
