@@ -26,12 +26,14 @@ private:
     QSettings mvSettings;
     QString mvCurrency1;
     QString mvCurrency2;
+    bool mvAutoUpdate;
     Edit *editDialog;
 
     void displayRate();
     void updateList();
 
 private slots:
+    void on_checkBox_AutoUpdate_clicked(bool checked);
     void on_pushButton_Edit_clicked();
     void on_pushButton_Apply_clicked();
     void on_listWidget2_clicked(QModelIndex index);
