@@ -39,85 +39,175 @@ void MainWindow::changeEvent(QEvent *e)
 }
 
 void MainWindow::initialSettings()
-{
-    if (!mvSettings.contains("AutoUpdate")) {
-        mvSettings.setValue("AutoUpdate", true);
-    }
-
-    if (mvSettings.value("Restore").toInt() < 1) {
-        mvSettings.setValue("Restore", 1);
+{  
+    if (mvSettings.value("Restore").toInt() < 2) {
+        mvSettings.remove("");
+        mvSettings.setValue("Restore", 2);
         mvSettings.setValue("Currency1", "EUR");
         mvSettings.setValue("Currency2", "USD");
         mvSettings.setValue("TaxRate", 20);
         mvSettings.setValue("TipRate", 10);
         mvSettings.setValue("Currency/EUR", 1);
-        mvSettings.setValue("Currency/USD", 1.4374);
-        mvSettings.setValue("Currency/JPY", 130.76);
+        mvSettings.setValue("Currency/AED", 0);
+        mvSettings.setValue("Currency/ANG", 0);
+        mvSettings.setValue("Currency/AOA", 0);
+        mvSettings.setValue("Currency/ARS", 0);
+        mvSettings.setValue("Currency/AUD", 1.5547);
+        mvSettings.setValue("Currency/BBD", 0);
         mvSettings.setValue("Currency/BGN", 1.9558);
+        mvSettings.setValue("Currency/BHD", 0);
+        mvSettings.setValue("Currency/BMD", 0);
+        mvSettings.setValue("Currency/BND", 0);
+        mvSettings.setValue("Currency/BRL", 2.5438);
+        mvSettings.setValue("Currency/BSD", 0);
+        mvSettings.setValue("Currency/CAD", 1.4752);
+        mvSettings.setValue("Currency/CHF", 1.4756);
+        mvSettings.setValue("Currency/CLP", 0);
+        mvSettings.setValue("Currency/CNY", 9.8130);
+        mvSettings.setValue("Currency/CVE", 0);
         mvSettings.setValue("Currency/CZK", 25.947);
         mvSettings.setValue("Currency/DKK", 7.4420);
         mvSettings.setValue("Currency/EEK", 15.6466);
+        mvSettings.setValue("Currency/DOP", 0);
+        mvSettings.setValue("Currency/EGP", 0);
+        mvSettings.setValue("Currency/FJD", 0);
         mvSettings.setValue("Currency/GBP", 0.88105);
+        mvSettings.setValue("Currency/GYD", 0);
+        mvSettings.setValue("Currency/HKD", 11.1536);
+        mvSettings.setValue("Currency/HRK", 7.2890);
         mvSettings.setValue("Currency/HUF", 266.80);
+        mvSettings.setValue("Currency/IDR", 13245.61);
+        mvSettings.setValue("Currency/ILS", 0);
+        mvSettings.setValue("Currency/INR", 65.7000);
+        mvSettings.setValue("Currency/IRR", 0);
+        mvSettings.setValue("Currency/JMD", 0);
+        mvSettings.setValue("Currency/JPY", 130.76);
+        mvSettings.setValue("Currency/KES", 0);
+        mvSettings.setValue("Currency/KHR", 0);
+        mvSettings.setValue("Currency/KRW", 1614.29);
+        mvSettings.setValue("Currency/KWD", 0);
+        mvSettings.setValue("Currency/KYD", 0);
+        mvSettings.setValue("Currency/KZT", 0);
         mvSettings.setValue("Currency/LTL", 3.4528);
         mvSettings.setValue("Currency/LVL", 0.7085);
-        mvSettings.setValue("Currency/PLN", 4.0399);
-        mvSettings.setValue("Currency/RON", 4.1043);
-        mvSettings.setValue("Currency/SEK", 10.1430);
-        mvSettings.setValue("Currency/CHF", 1.4756);
-        mvSettings.setValue("Currency/NOK", 8.1430);
-        mvSettings.setValue("Currency/HRK", 7.2890);
-        mvSettings.setValue("Currency/RUB", 42.5015);
-        mvSettings.setValue("Currency/TRY", 2.0900);
-        mvSettings.setValue("Currency/AUD", 1.5547);
-        mvSettings.setValue("Currency/BRL", 2.5438);
-        mvSettings.setValue("Currency/CAD", 1.4752);
-        mvSettings.setValue("Currency/CNY", 9.8130);
-        mvSettings.setValue("Currency/HKD", 11.1536);
-        mvSettings.setValue("Currency/IDR", 13245.61);
-        mvSettings.setValue("Currency/INR", 65.7000);
-        mvSettings.setValue("Currency/KRW", 1614.29);
+        mvSettings.setValue("Currency/MAD", 0);
+        mvSettings.setValue("Currency/MOP", 0);
         mvSettings.setValue("Currency/MXN", 18.2790);
         mvSettings.setValue("Currency/MYR", 4.8002);
+        mvSettings.setValue("Currency/MZN", 0);
+        mvSettings.setValue("Currency/NOK", 8.1430);
         mvSettings.setValue("Currency/NZD", 1.9497);
+        mvSettings.setValue("Currency/OMR", 0);
+        mvSettings.setValue("Currency/PAB", 0);
+        mvSettings.setValue("Currency/PEN", 0);
         mvSettings.setValue("Currency/PHP", 65.867);
+        mvSettings.setValue("Currency/PKR", 0);
+        mvSettings.setValue("Currency/PLN", 4.0399);
+        mvSettings.setValue("Currency/QAR", 0);
+        mvSettings.setValue("Currency/RON", 4.1043);
+        mvSettings.setValue("Currency/RSD", 0);
+        mvSettings.setValue("Currency/RUB", 42.5015);
+        mvSettings.setValue("Currency/SAR", 0);
+        mvSettings.setValue("Currency/SEK", 10.1430);
         mvSettings.setValue("Currency/SGD", 1.9984);
+        mvSettings.setValue("Currency/STD", 0);
+        mvSettings.setValue("Currency/SYP", 0);
         mvSettings.setValue("Currency/THB", 47.244);
+        mvSettings.setValue("Currency/TRY", 2.0900);
+        mvSettings.setValue("Currency/TTD", 0);
+        mvSettings.setValue("Currency/TWD", 0);
+        mvSettings.setValue("Currency/UAH", 0);
+        mvSettings.setValue("Currency/USD", 1.4374);
+        mvSettings.setValue("Currency/VEF", 0);
+        mvSettings.setValue("Currency/VND", 0);
+        mvSettings.setValue("Currency/XAF", 0);
+        mvSettings.setValue("Currency/XCD", 0);
+        mvSettings.setValue("Currency/XOF", 0);
+        mvSettings.setValue("Currency/YER", 0);
         mvSettings.setValue("Currency/ZAR", 10.6588);
+
         mvSettings.setValue("CurrencyName/EUR", "Euro");
-        mvSettings.setValue("CurrencyName/USD", "US dollar");
-        mvSettings.setValue("CurrencyName/JPY", "Japanese yen");
-        mvSettings.setValue("CurrencyName/BGN", "Bulgarian lev");
-        mvSettings.setValue("CurrencyName/CZK", "Czech koruna");
-        mvSettings.setValue("CurrencyName/DKK", "Danish krone");
-        mvSettings.setValue("CurrencyName/EEK", "Estonian kroon");
-        mvSettings.setValue("CurrencyName/GBP", "Pound sterling");
-        mvSettings.setValue("CurrencyName/HUF", "Hungarian forint");
+        mvSettings.setValue("CurrencyName/AED", "United Arab Emirates Dirham");
+        mvSettings.setValue("CurrencyName/ANG", "Netherlands Antilles Guilder");
+        mvSettings.setValue("CurrencyName/AOA", "Angola Kwanza");
+        mvSettings.setValue("CurrencyName/ARS", "Argentina Peso");
+        mvSettings.setValue("CurrencyName/AUD", "Australia Dollar");
+        mvSettings.setValue("CurrencyName/BBD", "Barbados Dollar");
+        mvSettings.setValue("CurrencyName/BGN", "Bulgaria Lev");
+        mvSettings.setValue("CurrencyName/BHD", "Bahrain Dinar");
+        mvSettings.setValue("CurrencyName/BMD", "Bermuda Dollar");
+        mvSettings.setValue("CurrencyName/BND", "Brunei Dollar");
+        mvSettings.setValue("CurrencyName/BRL", "Brazil Real");
+        mvSettings.setValue("CurrencyName/BSD", "Bahamas Dollar");
+        mvSettings.setValue("CurrencyName/CAD", "Canada Dollar");
+        mvSettings.setValue("CurrencyName/CHF", "Swiss Franc");
+        mvSettings.setValue("CurrencyName/CLP", "Chile Peso");
+        mvSettings.setValue("CurrencyName/CNY", "China Yuan");
+        mvSettings.setValue("CurrencyName/CVE", "Cape Verde Escudo");
+        mvSettings.setValue("CurrencyName/CZK", "Czech Republic Koruna");
+        mvSettings.setValue("CurrencyName/DKK", "Denmark Krone");
+        mvSettings.setValue("CurrencyName/DOP", "Dominican Republic Peso");
+        mvSettings.setValue("CurrencyName/EEK", "Estonia Kroon");
+        mvSettings.setValue("CurrencyName/EGP", "Egypt Pound");
+        mvSettings.setValue("CurrencyName/FJD", "Fiji Dollar");
+        mvSettings.setValue("CurrencyName/GBP", "United Kingdom Pound");
+        mvSettings.setValue("CurrencyName/GYD", "Guyana Dollar");
+        mvSettings.setValue("CurrencyName/HKD", "Hong Kong dollar");
+        mvSettings.setValue("CurrencyName/HRK", "Croatia Kuna");
+        mvSettings.setValue("CurrencyName/HUF", "Hungaria Forint");
+        mvSettings.setValue("CurrencyName/IDR", "Indonesia Rupiah");
+        mvSettings.setValue("CurrencyName/ILS", "Israel New Shekel");
+        mvSettings.setValue("CurrencyName/INR", "India Rupee");
+        mvSettings.setValue("CurrencyName/IRR", "Iran Rial");
+        mvSettings.setValue("CurrencyName/JMD", "Jamaica Dollar");
+        mvSettings.setValue("CurrencyName/JPY", "Japan Yen");
+        mvSettings.setValue("CurrencyName/KES", "Kenya Schilling");
+        mvSettings.setValue("CurrencyName/KHR", "Cambodia Riel");
+        mvSettings.setValue("CurrencyName/KRW", "South Korea Won");
+        mvSettings.setValue("CurrencyName/KWD", "Kuwait Dinar");
+        mvSettings.setValue("CurrencyName/KYD", "Cayman Islands Dollar");
+        mvSettings.setValue("CurrencyName/KZT", "Kazakhstan Tenge");
         mvSettings.setValue("CurrencyName/LTL", "Lithuanian litas");
         mvSettings.setValue("CurrencyName/LVL", "Latvian lats");
-        mvSettings.setValue("CurrencyName/PLN", "Polish zloty");
-        mvSettings.setValue("CurrencyName/RON", "Romanian leu");
-        mvSettings.setValue("CurrencyName/SEK", "Swedish krona");
-        mvSettings.setValue("CurrencyName/CHF", "Swiss franc");
-        mvSettings.setValue("CurrencyName/NOK", "Norwegian krone");
-        mvSettings.setValue("CurrencyName/HRK", "Croatian kuna");
-        mvSettings.setValue("CurrencyName/RUB", "Russian rouble");
-        mvSettings.setValue("CurrencyName/TRY", "Turkish lira");
-        mvSettings.setValue("CurrencyName/AUD", "Australian dollar");
-        mvSettings.setValue("CurrencyName/BRL", "Brasilian real");
-        mvSettings.setValue("CurrencyName/CAD", "Canadian dollar");
-        mvSettings.setValue("CurrencyName/CNY", "Chinese yuan renminbi");
-        mvSettings.setValue("CurrencyName/HKD", "Hong Kong dollar");
-        mvSettings.setValue("CurrencyName/IDR", "Indonesian rupiah");
-        mvSettings.setValue("CurrencyName/INR", "Indian rupee");
-        mvSettings.setValue("CurrencyName/KRW", "South Korean won");
-        mvSettings.setValue("CurrencyName/MXN", "Mexican peso");
-        mvSettings.setValue("CurrencyName/MYR", "Malaysian ringgit");
-        mvSettings.setValue("CurrencyName/NZD", "New Zealand dollar");
-        mvSettings.setValue("CurrencyName/PHP", "Philippine peso");
-        mvSettings.setValue("CurrencyName/SGD", "Singapore dollar");
-        mvSettings.setValue("CurrencyName/THB", "Thai baht");
-        mvSettings.setValue("CurrencyName/ZAR", "South African rand");
+        mvSettings.setValue("CurrencyName/MAD", "Morocco Dirham");
+        mvSettings.setValue("CurrencyName/MOP", "Macau Pataca");
+        mvSettings.setValue("CurrencyName/MXN", "Mexico Peso");
+        mvSettings.setValue("CurrencyName/MYR", "Malaysia Ringgit");
+        mvSettings.setValue("CurrencyName/MZN", "Mozambican Metical");
+        mvSettings.setValue("CurrencyName/NOK", "Norway Krone");
+        mvSettings.setValue("CurrencyName/NZD", "New Zealand Dollar");
+        mvSettings.setValue("CurrencyName/OMR", "Oman Rial");
+        mvSettings.setValue("CurrencyName/PAB", "Panama Balboa");
+        mvSettings.setValue("CurrencyName/PEN", "Peru Neuevo Sol");
+        mvSettings.setValue("CurrencyName/PHP", "Philippine Peso");
+        mvSettings.setValue("CurrencyName/PKR", "Pakistan Rupee");
+        mvSettings.setValue("CurrencyName/PLN", "Poland Zloty");
+        mvSettings.setValue("CurrencyName/QAR", "Qatar Rial");
+        mvSettings.setValue("CurrencyName/RON", "Romania Leu");
+        mvSettings.setValue("CurrencyName/RSD", "Serbia Dinar");
+        mvSettings.setValue("CurrencyName/RUB", "Russia Rouble");
+        mvSettings.setValue("CurrencyName/SAR", "Saudi Arabia Riyal");
+        mvSettings.setValue("CurrencyName/SEK", "Sweden Krona");
+        mvSettings.setValue("CurrencyName/SGD", "Singapore Dollar");
+        mvSettings.setValue("CurrencyName/STD", "Sao Tome and Principe Dobra");
+        mvSettings.setValue("CurrencyName/SYP", "Syrian Pound");
+        mvSettings.setValue("CurrencyName/THB", "Thailand Baht");
+        mvSettings.setValue("CurrencyName/TRY", "Turkey Lira");
+        mvSettings.setValue("CurrencyName/TTD", "Trinidad and Tobago Dollar");
+        mvSettings.setValue("CurrencyName/TWD", "Taiwan Dollar");
+        mvSettings.setValue("CurrencyName/UAH", "Ukraine Hryvnia");
+        mvSettings.setValue("CurrencyName/USD", "United States Dollar");
+        mvSettings.setValue("CurrencyName/VEF", "Venezuelan Bolivar Fuerte");
+        mvSettings.setValue("CurrencyName/VND", "Vietnam Dong");
+        mvSettings.setValue("CurrencyName/XAF", "Central African CFA Franc");
+        mvSettings.setValue("CurrencyName/XCD", "East Caribbean Dollar");
+        mvSettings.setValue("CurrencyName/XOF", "West African CFA Franc");
+        mvSettings.setValue("CurrencyName/YER", "Yemen Rial");
+        mvSettings.setValue("CurrencyName/ZAR", "South Africa Rand");
+    }
+
+    if (!mvSettings.contains("AutoUpdate")) {
+        mvSettings.setValue("AutoUpdate", true);
     }
 
 }
@@ -282,13 +372,47 @@ void MainWindow::updateCurrency()
     QNetworkAccessManager manager;
     QEventLoop loop;
     QTimer *timer = new QTimer(this);
-    QNetworkRequest *request = new QNetworkRequest(QUrl("http://www.ecb.europa.eu/stats/eurofxref/eurofxref-daily.xml"));
-    QNetworkReply *reply = manager.get(*request);
+    QNetworkRequest *request; // = new QNetworkRequest(QUrl("http://www.ecb.europa.eu/stats/eurofxref/eurofxref-daily.xml"));
+    QNetworkReply *reply; // = manager.get(*request);
+
+    request = new QNetworkRequest(QUrl("http://rss.timegenie.com/forex2.xml"));
+    reply = manager.get(*request);
 
     connect(reply, SIGNAL(finished()), &loop, SLOT(quit()));
     connect(timer, SIGNAL(timeout()), &loop, SLOT(quit()));
 
-    ui->label->setText("Updating...");
+    ui->label->setText("Time Genie...");
+
+    loop.exec();
+    timer->start(10000);
+    xml.clear();
+    xml.addData(reply->readAll());
+
+    delete reply;
+
+    while (!xml.atEnd()) {
+        if (xml.isStartElement()) {
+            if (xml.name() == "currency") {
+                QXmlStreamAttributes attrs = xml.attributes();
+                QStringRef currencyName = attrs.value("code");
+                QStringRef currencyRate = attrs.value("rate");
+                if (!currencyName.isEmpty()) {
+                    mvSettings.setValue("Currency/" + currencyName.toString(), currencyRate.toString());
+                }
+            }
+        }
+        xml.readNext();
+    }
+
+    delete request;
+
+    request = new QNetworkRequest(QUrl("http://www.ecb.europa.eu/stats/eurofxref/eurofxref-daily.xml"));
+    reply = manager.get(*request);
+
+    connect(reply, SIGNAL(finished()), &loop, SLOT(quit()));
+    connect(timer, SIGNAL(timeout()), &loop, SLOT(quit()));
+
+    ui->label->setText("ECB...");
 
     loop.exec();
     timer->start(10000);
